@@ -352,8 +352,10 @@ invertModInternal
   :: Natural -- Value
   -> Natural -- Modulo
   -> Maybe Natural
+invertModInternal 0 1 = Just 0
 invertModInternal x m = case integerRecipMod# (toInteger x) m of
-  (# | () #) -> Nothing
+  -- See https://gitlab.haskell.org/ghc/ghc/-/issues/26017
+  (# | () #) -> if m == 1 then Just 0 else Nothing
   (# y | #)  -> Just y
 {-# INLINABLE invertModInternal #-}
 
@@ -383,11 +385,10 @@ mx ^% a
 #endif
 {-# INLINABLE [1] (^%) #-}
 
-{-# SPECIALISE [1] (^%) ::
-  KnownNat m => Mod m -> Integer -> Mod m,
-  KnownNat m => Mod m -> Natural -> Mod m,
-  KnownNat m => Mod m -> Int     -> Mod m,
-  KnownNat m => Mod m -> Word    -> Mod m #-}
+{-# SPECIALISE [1] (^%) :: KnownNat m => Mod m -> Integer -> Mod m #-}
+{-# SPECIALISE [1] (^%) :: KnownNat m => Mod m -> Natural -> Mod m #-}
+{-# SPECIALISE [1] (^%) :: KnownNat m => Mod m -> Int     -> Mod m #-}
+{-# SPECIALISE [1] (^%) :: KnownNat m => Mod m -> Word    -> Mod m #-}
 
 {-# RULES
 "powMod/2/Integer"     forall x. x ^% (2 :: Integer) = let u = x in u*u
