@@ -335,6 +335,8 @@ invertMod :: KnownNat m => Mod m -> Maybe (Mod m)
 invertMod mx@(Mod !x) = case natVal mx of
   NatJ#{}   -> tooLargeModulus
   NatS# 0## -> Nothing
+  -- See https://gitlab.haskell.org/ghc/ghc/-/issues/26017
+  NatS# 1## -> Just 0
   NatS# m#  -> Mod <$> invertModWord x (W# m#)
 
 invertModWord :: Word -> Word -> Maybe Word
@@ -442,11 +444,10 @@ mx@(Mod !x) ^% a = case natVal mx of
       f b  e acc = f (mulMod m b b) (e `P.quot` 2) (if odd e then mulMod m b acc else acc)
 {-# INLINABLE [1] (^%) #-}
 
-{-# SPECIALISE [1] (^%) ::
-  KnownNat m => Mod m -> Integer -> Mod m,
-  KnownNat m => Mod m -> Natural -> Mod m,
-  KnownNat m => Mod m -> Int     -> Mod m,
-  KnownNat m => Mod m -> Word    -> Mod m #-}
+{-# SPECIALISE [1] (^%) :: KnownNat m => Mod m -> Integer -> Mod m #-}
+{-# SPECIALISE [1] (^%) :: KnownNat m => Mod m -> Natural -> Mod m #-}
+{-# SPECIALISE [1] (^%) :: KnownNat m => Mod m -> Int     -> Mod m #-}
+{-# SPECIALISE [1] (^%) :: KnownNat m => Mod m -> Word    -> Mod m #-}
 
 {-# RULES
 "powMod/2/Integer"     forall x. x ^% (2 :: Integer) = let u = x in u*u
